@@ -25,7 +25,7 @@
 #include <locale.h>
 
 #include <glib.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include <fontconfig/fontconfig.h>
