@@ -551,8 +551,8 @@ on_output_changed_cb (CcDisplayArrangement *self,
 static gint
 sort_outputs_by_disabled (gconstpointer a, gconstpointer b)
 {
-    CcDisplayMonitor *ma = CC_DISPLAY_MONITOR (a);
-    CcDisplayMonitor *mb = CC_DISPLAY_MONITOR (b);
+    CcDisplayMonitor *ma = CC_DISPLAY_MONITOR ((gpointer) a);
+    CcDisplayMonitor *mb = CC_DISPLAY_MONITOR ((gpointer) b);
 
     if (!cc_display_monitor_is_active (ma) && cc_display_monitor_is_active (mb))
         return -1;
@@ -561,7 +561,7 @@ sort_outputs_by_disabled (gconstpointer a, gconstpointer b)
     if (cc_display_monitor_is_active (ma) && !cc_display_monitor_is_active (mb))
         return 1;
 
-    return cc_display_monitor_get_ui_number (a) < cc_display_monitor_get_ui_number (b) ? -1 : 1;
+    return cc_display_monitor_get_ui_number ((gpointer) a) < cc_display_monitor_get_ui_number ((gpointer) b) ? -1 : 1;
 }
 
 static gboolean
@@ -607,7 +607,7 @@ cc_display_arrangement_draw (GtkWidget *widget,
       GdkRGBA bg_rgba;
       gint x1, y1, x2, y2;
       gint w, h;
-      gint num;
+      gint ui_number, color_index;
 
       if (!cc_display_monitor_is_usable (output))
         continue;
@@ -626,9 +626,6 @@ cc_display_arrangement_draw (GtkWidget *widget,
       if (cc_display_monitor_is_primary (output) || cc_display_config_is_cloning (self->config))
         gtk_style_context_add_class (context, "primary");
 
-      /* Set in cc-display-panel.c */
-      num = cc_display_monitor_get_ui_number (output);
-
       monitor_get_drawing_rect (self, output, &x1, &y1, &x2, &y2);
       w = x2 - x1;
       h = y2 - y1;
@@ -656,9 +653,13 @@ cc_display_arrangement_draw (GtkWidget *widget,
 
       cairo_save (cr);
 
+      /* Set in cc-display-panel.c */
+      ui_number = cc_display_monitor_get_ui_number (output);
+      color_index = ui_number - 1; // ui_numbers start at 1, our color index is 0-based.
+
       gchar *rgba_str;
 
-      g_signal_emit_by_name (G_OBJECT (widget), "get-output-color", output, &rgba_str);
+      g_signal_emit_by_name (G_OBJECT (widget), "get-output-color", color_index, &rgba_str);
 
       if (gdk_rgba_parse (&bg_rgba, rgba_str))
         {
@@ -685,7 +686,7 @@ cc_display_arrangement_draw (GtkWidget *widget,
 
       cairo_translate (cr, border.left + padding.left, border.top + padding.top);
 
-      if (num > 0)
+      if (ui_number > 0)
         {
           PangoLayout *layout;
           PangoFontDescription *font = NULL;
@@ -703,10 +704,11 @@ cc_display_arrangement_draw (GtkWidget *widget,
 
           cairo_translate (cr, margin.left, margin.top);
 
-          number_str = g_strdup_printf ("%d", num);
+          number_str = g_strdup_printf ("%d", ui_number);
           gtk_style_context_get (context, state, "font", &font, NULL);
           layout = gtk_widget_create_pango_layout (GTK_WIDGET (self), number_str);
           pango_layout_set_font_description (layout, font);
+          pango_font_description_free (font);
           pango_layout_get_extents (layout, NULL, &extents);
 
           h = (extents.height - extents.y) / PANGO_SCALE;
@@ -970,7 +972,7 @@ cc_display_arrangement_class_init (CcDisplayArrangementClass *klass)
                 CC_TYPE_DISPLAY_ARRANGEMENT,
                 G_SIGNAL_RUN_LAST,
                 0, NULL, NULL, NULL,
-                G_TYPE_STRING, 1, CC_TYPE_DISPLAY_MONITOR);
+                G_TYPE_STRING, 1, G_TYPE_INT);
 }
 
 static void
