@@ -353,7 +353,7 @@ update_current_tool (CcWacomPanel  *panel,
 }
 
 static gboolean
-on_event (GtkWidget    *wigdet,
+on_event (GtkWidget    *widget,
           GdkEvent     *event,
           CcWacomPanel *panel)
 {
@@ -715,4 +715,4 @@ cc_wacom_panel_register (GIOModule *module)
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     g_io_extension_point_implement (CC_SHELL_PANEL_EXTENSION_POINT,
                     CC_TYPE_WACOM_PANEL, "wacom", 0);
-}
\ No newline at end of file
+}
